package articles;

import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Collections;
import java.util.Comparator;
import java.util.Scanner;
import java.util.Vector;

import javax.swing.AbstractListModel;

public class ArticleListModel extends AbstractListModel {

    String s;

    Vector<Article> artikli;

    public void sortByName() {
	Collections.sort(artikli);
	fireContentsChanged(this, 0, getSize() - 1);
    }

    public void sortByPrice() {
	Collections.sort(artikli, new Comparator<Article>() {
	    @Override
	    public int compare(Article arg0, Article arg1) {
		return arg0.price - arg1.price;
	    }
	});
	fireContentsChanged(this, 0, getSize() - 1);
    }

    public void add(Article artikal) {
	artikli.add(artikal);
	fireIntervalAdded(this, getSize() - 1, getSize() - 1);
    }

    public void edit(int index, int id, String naziv, int cena) {
	artikli.get(index).ID = id;
	artikli.get(index).name = naziv;
	artikli.get(index).price = cena;
	fireContentsChanged(this, index, index);
    }

    public void delete(int index) {
	artikli.remove(index);
	fireIntervalRemoved(this, index, index);
    }

    public void deleteAll() {
	artikli.removeAllElements();
	fireIntervalRemoved(this, 0, getSize());
    }

    public void load(String datoteka) {
	Scanner sc = null;
	try {
	    sc = new Scanner(new FileReader(datoteka));
	} catch (FileNotFoundException e) {
	    System.out.println("Nema fajla " + datoteka);
	    System.exit(1);
	}

	// brisemo sve prethodne artikle?!
	deleteAll();
	while (sc.hasNextLine()) {
	    String podaci[] = sc.nextLine().split(" ");
	    add(new Article(Integer.parseInt(podaci[0]), podaci[1], Integer.parseInt(podaci[2])));
	}
	sc.close();
    }

    void save(String datoteka) {
	PrintWriter pw = null;
	try {
	    pw = new PrintWriter(new FileWriter(datoteka));
	} catch (IOException IOe) {
	    System.out.println("Neuspela operacija upisivanja u fajl");
	    System.exit(1);
	}

	for (int i = 0; i < getSize(); i++)
	    pw.println(getElementAt(i).toString());
	pw.close();
    }

    public ArticleListModel(Vector<Article> artikli) {
	this.artikli = artikli;
    }

    @Override
    public Object getElementAt(int arg0) {
	return artikli.get(arg0);
    }

    @Override
    public int getSize() {
	return artikli.size();
    }

}
